/* [create-plugin] version: 7.7.0 */
/* [create-plugin] plugin: alexanderzobnin-zabbix-app@6.5.0 */
define(["@grafana/data","@grafana/runtime","module"],(e,r,n)=>(()=>{"use strict";var t={7781(r){r.exports=e},8531(e){e.exports=r},1308(e){e.exports=n}};const a={};function o(e){const r=a[e];if(void 0!==r)return r.exports;const n=a[e]={exports:{}};return t[e](n,n.exports,o),n.exports}o.n=e=>{const r=e&&e.__esModule?()=>e.default:()=>e;return o.d(r,{a:r}),r},o.d=(e,r)=>{if(Array.isArray(r))for(var n=0;n<r.length;){var t=r[n++],a=r[n++];o.o(e,t)?0===a&&n++:0===a?Object.defineProperty(e,t,{enumerable:!0,value:r[n++]}):Object.defineProperty(e,t,{enumerable:!0,get:a})}else for(var t in r)o.o(r,t)&&!o.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:r[t]})},o.o=(e,r)=>Object.prototype.hasOwnProperty.call(e,r),o.r=e=>{Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},o.p="public/plugins/alexanderzobnin-zabbix-app/";let i={};o.r(i),o.d(i,{plugin:()=>u});var l=o(1308),s=o.n(l);o.p=s()&&s().uri?s().uri.slice(0,s().uri.lastIndexOf("/")+1):"public/plugins/alexanderzobnin-zabbix-app/";var p=o(7781);(0,o(8531).loadPluginCss)({dark:"plugins/alexanderzobnin-zabbix-app/styles/dark.css",light:"plugins/alexanderzobnin-zabbix-app/styles/light.css"});const u=new p.AppPlugin;return i})());
//# sourceMappingURL=module.js.map